"""About this package."""

__all__ = [
    "__title__",
    "__summary__",
    "__uri__",
    "__version__",
    "__author__",
    "__email__",
    "__license__",
    "__copyright__",
]

__title__ = "argo-workflows-dsl"
__summary__ = "DSL for Argo Workflows"
__uri__ = "https://github.com/CermakM/argo-python-dsl"

__version__ = "0.3.0"

__author__ = "Yudi Xue, Marek Cermak"
__email__ = "binarycrayon@gmail.com, macermak@redhat.com"

__license__ = "Apache Software License"
__copyright__ = "Copyright 2019 {0}".format(__author__)
